@@ -17,13 +17,13 @@ class RvbdHTTPException(RvbdException):
     def __init__(self, result, data, method, urlpath):
         RvbdException.__init__(self,
                                'HTTP %s on %s returned status %s (%s)' %
-                               (method, urlpath, result.status, result.reason))
+                               (method, urlpath, result.status_code, result.reason))
 
-        self.status = result.status
+        self.status = result.status_code
         self.reason = result.reason
         # Try to parse the error structure (either XML or JSON)
         try:
-            t = result.getheader('Content-type')
+            t = result.headers.get('Content-type', None)
             if t == 'text/xml':
                 e = ElementTree.fromstring(data)
                 if e.tag != 'error':
@@ -44,10 +44,13 @@ class RvbdHTTPException(RvbdException):
                     self.error_id = d['error_id']
                 except KeyError:
                     #for profiler
+                    self.error_id = None
                     self.error_text = d['status_text']
             elif self.reason == 'Unauthorized':
+                self.error_id = None
                 self.error_text = "Not authorized"
             else:
+                self.error_id = None
                 self.error_text = self.reason
 
             if self.error_text == "Not authorized":
