@@ -17,7 +17,8 @@ import time
 import cStringIO as StringIO
 
 from rvbd.profiler.filters import TimeFilter, TrafficFilter
-from rvbd.common.timeutils import parse_timedelta, datetime_to_seconds
+from rvbd.common.timeutils import (parse_timedelta, datetime_to_seconds, 
+                                   timedelta_total_seconds)
 from rvbd.common.utils import RecursiveUpdateDict
 from rvbd.common.exceptions import RvbdException
 
@@ -222,11 +223,8 @@ class Report(object):
         if resolution not in ["auto", "1min", "15min", "hour",
                               "6hour", "day", "week", "month"]:
             rd = parse_timedelta(resolution)
-            resolution = self.RESOLUTION_MAP[int(rd.total_seconds())]
+            resolution = self.RESOLUTION_MAP[int(timedelta_total_seconds(rd))]
 
-            raise ValueError('resolution "%s" invalid must be one of these values: '
-                             'auto, 1min, 15min, hour '
-                             '6hour, day, week, month' % resolution)
         self.resolution = resolution
 
         start = datetime_to_seconds(self.timefilter.start)
@@ -254,16 +252,15 @@ class Report(object):
 
         logger.debug("Posting JSON: %s" % to_post)
 
-        self.profiler.api.report.reports(data=to_post)
+        response = self.profiler.api.report.reports(data=to_post)
 
-        location = self.profiler.conn.last_http_response.getheader("Location")
-        m = re.match(".*reporting/reports/([0-9]+)$", location)
-        if not m:
+        try:
+            self.id = int(response['id'])
+        except KeyError:
             raise ValueError(
-                "failed to retrieve report id from location header: %s"
-                % location)
+                "failed to retrieve report id from report creation response: %s"
+                % response)
 
-        self.id = int(m.group(1))
         logger.info("Created report %d" % self.id)
 
         if sync:
