@@ -7,18 +7,17 @@
 
 
 
-class SharkAPIVersions:
+class SharkAPIVersions(object):
+    CURRENT = "5.0"
+    LEGACY = ["4.0"]
 
-    CURRENT = "4.0"
-    LEGACY = ["3.2", "3.1", "3.0"]
-
-class APIGroup:
+class APIGroup(object):
     '''Simple wrapper class for a group of related API functions'''
     def __init__(self, uri_prefix, shark):
         self.uri_prefix = uri_prefix
         self.shark = shark
 
-class APITimestampFormat:
+class APITimestampFormat(object):
     '''Encapsulation of the various options supported for absolute
     timestamp encoding.'''
     NANOSECOND             = "ns number"
@@ -35,4 +34,3 @@ class APITimestampFormat:
     SECOND_MICROSECOND_STR = "s.us string"
     SECOND_MILLISECOND     = "s.ms number"
     SECOND_MILLISECOND_STR = "s.ms string"
-
