@@ -54,7 +54,7 @@ class _FSResource(object):
             # renaming a directory, creating a sub-dir, moving a directory,
             # uploading a trace file). Only Shark can control the root
             # directory
-            if path == "/":
+            if path == self.shark._file_separator:
                 self.data = self._get_root_details()
             else:
                 self.data = self.shark.api.fs.get_details(path, details=True)
@@ -69,7 +69,7 @@ class _FSResource(object):
         root_dirs = self.shark.api.fs.get_all(details=True, recursive=True)
 
         data = {}
-        data["id"] = "/"
+        data["id"] = self.shark._file_separator
 
         # It would not make sense setting 0 here since that date would be
         # wrong
@@ -172,7 +172,7 @@ class _FSResource(object):
         """ Creation time timestamp
         """
         creation_time = None
-        if self.data["created"] != None:
+        if self.data["created"] is not None:
             creation_time = datetime.datetime.fromtimestamp(self.data["created"])
         return creation_time
 
@@ -182,12 +182,11 @@ class _FSResource(object):
         """ Modification time timestamp
         """
         modification_time = None
-        if self.data["modified"] != None:
+        if self.data["modified"] is not None:
             modification_time = datetime.datetime.fromtimestamp(self.data["modified"])
 
         return modification_time
 
-
 class Directory4(_FSResource):
 
     def __init__(self, shark, path):
@@ -198,7 +197,7 @@ class Directory4(_FSResource):
         super(Directory4, self).__init__(shark, d)
 
     def __repr__(self):
-        return "<Directory path='{0}'>".format(self.data.id)
+        return "<Directory path='{0}'>".format(self.data['id'])
 
     def _process_json_directories(self, json_data):
         """Process a json representing the directories
@@ -239,7 +238,7 @@ class Directory4(_FSResource):
             }
             shark.api.fs.upload_raw(src_dir, None, headers)
 
-            new_path = src_dir + "/" + dir_name
+            new_path = src_dir + shark._file_separator + dir_name
             return cls(shark, new_path)
 
         raise SharkException(error_msg + path + \
@@ -252,7 +251,7 @@ class Directory4(_FSResource):
         """
         assert self.shark is not None
 
-        complete_path = self.data["id"] + "/" + dir_name
+        complete_path = self.data["id"] + self.shark._file_separator + dir_name
         new_dir_ref = Directory4.create(self.shark, complete_path)
         self._update_details(self.data["id"])
         return new_dir_ref
@@ -266,12 +265,12 @@ class Directory4(_FSResource):
         #the get_details call has different result on / than on any
         #other directory, so we should take care of it
         res = self.shark.api.fs.get_details(
-            self.data["id"], details = True, recursive = recursive)
+            self.data["id"], details=True, recursive=recursive)
 
         dir_list = []
         file_list = []
 
-        if self.data['id'] == '/':
+        if self.data['id'] == self.shark._file_separator:
             #we are in the root case, res is thus a list of directories
             for directory in res:
                 dir_list.append(Directory4(self.shark, directory))
@@ -288,7 +287,7 @@ class Directory4(_FSResource):
         """
         assert self.shark is not None
 
-        complete_remote_path = self.data["id"] + "/" + remote_file_name
+        complete_remote_path = self.data["id"] + self.shark._file_separator + remote_file_name
         return TraceFile4.upload(self.shark, complete_remote_path, local_path)
     
 
@@ -316,10 +315,10 @@ class Directory4(_FSResource):
             
 
         for dir in dirs:
-            sub_data = data_lookup(data, dir.data.id)
+            sub_data = data_lookup(data, dir.data['id'])
             sub_dirs, sub_files = self._process_json_directories(sub_data)
         
-            yield dir.data.id, sub_dirs, sub_files
+            yield dir.data['id'], sub_dirs, sub_files
         
             for x in self._walk(sub_data, sub_dirs):
                 yield x
@@ -335,7 +334,7 @@ class Directory4(_FSResource):
         dirs = list()
         files = list()
 
-        if self.data['id'] == '/':
+        if self.data['id'] == self.shark._file_separator:
             for dir in res:
                 dirs.append(Directory4(self.shark, dir))
         else:
@@ -359,10 +358,10 @@ class File4(_FSResource, _InputSource):
 
     @property
     def source_path(self):
-        if self.data.id[0] == '/':
-            return 'fs' + self.data.id
+        if self.data['id'][0] == self.shark._file_separator:
+            return 'fs' + self.data['id']
         else:
-            return 'fs' + '/' + self.data.id
+            return 'fs' + self.shark._file_separator + self.data['id']
 
     @property
     def source_options(self):
@@ -371,12 +370,23 @@ class File4(_FSResource, _InputSource):
     @classmethod
     def get_all(cls, shark):
         res = list()
-        for directory in shark.api.fs.get_all():
-            for fi in directory['files']:
-                clss = cls._get_child_class(fi)
-                res.append(clss(shark, fi))
+        
+        for directory in shark.api.fs.get_all(recursive=True):
+            cls._get_all(shark, directory, res)
+            
         return res
+        
+    @classmethod
+    def _get_all(cls, shark, dirs, lst):        
+        for dir in dirs['dirs']:
+            cls._get_all(shark, dir, lst)
+            
+        for file in dirs['files']:
+            clss = cls._get_child_class(file)
+            lst.append(clss(shark, file))
 
+        return lst
+        
     @classmethod
     def _get_child_class(cls, fi):
         """Given a json representation of a file returns
@@ -481,7 +491,7 @@ class _AggregatedFile(File4):
         headers = {'Content-Disposition' : aggr_file_name}
         shark.api.fs.upload_xjobject(aggr_file_dir, json_dict, headers)
 
-        new_path = aggr_file_dir + "/" + aggr_file_name
+        new_path = aggr_file_dir + shark._file_separator + aggr_file_name
         if type == "MULTISEGMENT_FILE":
 
             return MultisegmentFile4(shark, {'id': new_path})
@@ -501,7 +511,7 @@ class _AggregatedFile(File4):
         dir_name, file_name = os.path.split(self.data["id"])
 
         for linked_file in self.data["linked_sources"]:
-            linked_file_path = dir_name + "/" + linked_file["path"]
+            linked_file_path = dir_name + self.shark._file_separator + linked_file["path"]
             trace_file_list.append(TraceFile4(self.shark, linked_file_path))
 
         return trace_file_list
@@ -549,7 +559,7 @@ class TraceFile4(File4):
 
         shark.api.fs.upload_raw(file_dir, local_file_ref, headers)
         local_file_ref.close()
-        new_path = file_dir + "/" + file_name
+        new_path = file_dir + shark._file_separator + file_name
         return TraceFile4(shark, {'id':new_path})
 
     def create_index(self):
@@ -671,8 +681,8 @@ class MultisegmentFile4(_AggregatedFile):
     def delete_timeskew(self):
         """Delete the timeskew computation on the trace file.
         """
-        error_msg = "An error deleting the timeskew calculation" \
-                    "on the multisegment file "
+        error_msg = ("An error deleting the timeskew calculation"
+                     "on the multisegment file ")
         assert self.shark is not None
         assert self.data is not None
 
