@@ -18,7 +18,6 @@ import traceback
 
 from rvbd.common.api_helpers import APIVersion
 from rvbd.common.service import Service
-from rvbd.shark._connection import SharkConnection
 from rvbd.shark._exceptions import SharkException
 from rvbd.shark._api_helpers import SharkAPIVersions
 from rvbd.shark._api4 import API4_0
@@ -30,27 +29,28 @@ from rvbd.shark._class_mapping import Classesv4, Classes, Classesv5
 FILTERS_MAP = {}
 
 API_TABLE = {
-    "4.0" : API4_0,
-    "5.0" : API5_0
-    }
+    "4.0": API4_0,
+    "5.0": API5_0
+}
 
 CLASS_TABLE = {
     '4.0': Classesv4,
     '5.0': Classesv5
-    }
+}
 
 
 from rvbd.shark.filters import TimeFilter
 
 __all__ = ['Shark']
 
+
 class Shark(Service):
     """The Shark class is the main interface to interact with a Shark Appliance.
     Among other things, it makes it possible to manage views, jobs, files and
     trace clips, and to query and modify the appliance settings.
     """
     def __init__(self, host, port=None, auth=None,
-                 force_version=None, force_ssl=None):
+                 force_version=None):
         """Establishes a connection to a Shark appliance.
 
         `host` is the name or IP address of the Shark to connect to
@@ -80,8 +80,8 @@ class Shark(Service):
                        [APIVersion(v) for v in SharkAPIVersions.LEGACY]
 
         super(Shark, self).__init__("shark", host, port=port, auth=auth,
-                                    force_ssl=force_ssl, versions=versions)
-        
+                                    versions=versions)
+
         self.api = API_TABLE[str(self.api_version)](self)
         self.classes = CLASS_TABLE[str(self.api_version)]()
         #these module may not be available
@@ -90,6 +90,9 @@ class Shark(Service):
         except NotImplementedError:
             self.settings = Classes()
 
+        # Get the server info
+        self.serverinfo = self.get_serverinfo()
+
         self.views = {}
         self._interfaces = None
         self.xtfields = {}
@@ -111,15 +114,6 @@ class Shark(Service):
         else:
             return '<Shark %s>' % (self.host)
 
-    def _get_connection_class(self):
-        """Internal function to return the class
-        used to instantiate a connection"""
-        def conn_wrap(*args, **kwargs):
-            if 'pool_size' not in kwargs:
-                kwargs['pool_size'] = 4
-            return SharkConnection(*args, **kwargs)
-        return conn_wrap
-
     def _get_supported_versions(self):
         try:
             # First try the standard GL7 method
@@ -128,7 +122,6 @@ class Shark(Service):
             if versions:
                 return versions
         except:
-            import traceback
             traceback.print_exc()
             pass
 
@@ -521,7 +514,7 @@ class Shark(Service):
 
         Return Value: a named tuple with the server parameters
         '''
-        return self.api.system.get_info(self)
+        return self.api.system.get_info()
 
     def get_stats(self):
         '''Get the Shark appliance storage info
@@ -626,3 +619,11 @@ class Shark(Service):
         """Returns the Shark software model
         """
         return self.api.common.info().get('model')
+    
+    @property
+    def _file_separator(self):
+        # Get the file separator based on the server OS
+        if self.serverinfo['system_type'] == "Windows":
+            return "\\"
+        else:
+            return "/"
